pyparsing.pyparsing.Regex

Package pyparsing :: Module pyparsing :: Class Regex |
[frames | no frames]

## Type Regex

       object --+
                |
    ParserElement --+
                    |
                Token --+
                        |
                       Regex

Token for matching strings that match a given regular expression. Defined with string specifying the regular expression in a form recognized by the inbuilt Python re module.

Method Summary
| ``__init__`(self, pattern, flags)` The parameters pattern and flags are passed to the re.compile() function as-is.
| `__str__(self)`
| `parseImpl(self, instring, loc, doActions)`
Inherited from `Token`: `setName` Inherited from `ParserElement`: `__add__`, `__and__`, `__call__`, `__eq__`, `__getattr__`, `__invert__`, `__mul__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__req__`, `__rmul__`, `__ror__`, `__rxor__`, `__xor__`, `addParseAction`, `checkRecursion`, `copy`, `enablePackrat`, `getException`, `ignore`, `leaveWhitespace`, `parseFile`, `parseString`, `parseWithTabs`, `postParse`, `preParse`, `resetCache`, `scanString`, `searchString`, `setBreak`, `setDebug`, `setDebugActions`, `setDefaultWhitespaceChars`, `setFailAction`, `setParseAction`, `setResultsName`, `setWhitespaceChars`, `streamline`, `suppress`, `transformString`, `tryParse`, `validate` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variable Summary
`list` | `__slotnames__` = `[]`
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`

Instance Method Details

### __init__(self, pattern, flags=0) (Constructor) The parameters pattern and flags are passed to the re.compile() function as-is. See the Python re module for an explanation of the acceptable patterns and flags. Overrides: `pyparsing.pyparsing.Token.__init__`

Class Variable Details

    ### __slotnames__ Type: `list` Value:
        []

Generated by Epydoc 2.1 on Sun Feb 10 18:01:06 2008 | http://epydoc.sf.net